@@ -4,11 +4,13 @@ use warnings;
 
 use Test2::Util::HashBase qw/trace nested _meta/;
 
-sub causes_fail  { 0 }
+sub causes_fail      { 0 }
+sub increments_count { 0 }
 
-sub update_state {()};
-sub terminate    {()};
-sub global       {()};
+sub callback { }
+
+sub terminate { () }
+sub global    { () }
 
 sub set_meta {
     my $self = shift;
@@ -23,6 +25,8 @@ sub get_meta {
     my $self = shift;
     my ($key, $default) = @_;
 
+    return undef unless $self->{+_META} || $default;
+
     $self->{+_META} ||= {};
 
     $self->{+_META}->{$key} = $default
@@ -92,6 +96,17 @@ generated
 Returns true if this event should result in a test failure. In general this
 should be false.
 
+=item $bool = $e->increments_count
+
+Should be true if this event should result in a test count increment.
+
+=item $e->callback($hub)
+
+If your event needs to have extra effects on the L<Test2::Hub> you can override
+this method.
+
+This is called B<BEFORE> your event is passed to the formatter.
+
 =item $call = $e->created
 
 Get the C<caller()> details from when the event was generated. This is usually
@@ -102,13 +117,6 @@ inside a tools package. This is typically used for debugging.
 If this event is nested inside of other events, this should be the depth of
 nesting. (This is mainly for subtests)
 
-=item $e->update_state($state)
-
-This callback is used by L<Test2::Hub> to give your event a chance to
-update the state.
-
-This is called B<BEFORE> your event is passed to the formatter.
-
 =item $bool = $e->global
 
 Set this to true if your event is global, that is ALL threads and processes
@@ -157,6 +165,23 @@ event then the default will be attached and returned.
     # Get the value, or set it to 'xxx' and get that.
     my $val = $e->get_meta('Foo::Bar', 'xxx');
 
+=item $todo = $e->todo
+
+=item $e->set_todo($todo)
+
+Get/Set the todo reason on the event. Any value other than C<undef> makes the
+event 'TODO'.
+
+Not all events make use of this field, but they can all have it set/cleared.
+
+=item $bool = $e->diag_todo
+
+=item $e->diag_todo($todo)
+
+True if this event should be considered 'TODO' for diagnostics purposes. This
+essentially means that any message that would go to STDERR will go to STDOUT
+instead so that a harness will hide it outside of verbose mode.
+
 =back
 
 =head1 SOURCE
